[llvm-commits] [llvm] r136677 - in /llvm/trunk: include/llvm/Analysis/ScalarEvolution.h lib/Analysis/ScalarEvolution.cpp

Andrew Trick atrick at apple.com
Mon Aug 1 21:23:35 PDT 2011


Author: atrick
Date: Mon Aug  1 23:23:35 2011
New Revision: 136677

URL: http://llvm.org/viewvc/llvm-project?rev=136677&view=rev
Log:
Use consistent terminology for loop exit/exiting blocks. Name change only.

Modified:
    llvm/trunk/include/llvm/Analysis/ScalarEvolution.h
    llvm/trunk/lib/Analysis/ScalarEvolution.cpp

Modified: llvm/trunk/include/llvm/Analysis/ScalarEvolution.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/Analysis/ScalarEvolution.h?rev=136677&r1=136676&r2=136677&view=diff
==============================================================================
--- llvm/trunk/lib/Analysis/ScalarEvolution.cpp (original)
+++ llvm/trunk/lib/Analysis/ScalarEvolution.cpp Mon Aug  1 23:23:35 2011
@@ -3814,10 +3814,10 @@
 //
 
 // getExitCount - Get the expression for the number of loop iterations for which
-// this loop is guaranteed not to exit via ExitBlock. Otherwise return
+// this loop is guaranteed not to exit via ExitintBlock. Otherwise return
 // SCEVCouldNotCompute.
-const SCEV *ScalarEvolution::getExitCount(Loop *L, BasicBlock *ExitBlock) {
-  return getBackedgeTakenInfo(L).getExact(ExitBlock, this);
+const SCEV *ScalarEvolution::getExitCount(Loop *L, BasicBlock *ExitingBlock) {
+  return getBackedgeTakenInfo(L).getExact(ExitingBlock, this);
 }
 
 /// getBackedgeTakenCount - If the specified loop has a predictable
@@ -4002,7 +4002,7 @@
   if (!ExitNotTaken.isCompleteList()) return SE->getCouldNotCompute();
 
   // We need at least one computable exit.
-  if (!ExitNotTaken.ExitBlock) return SE->getCouldNotCompute();
+  if (!ExitNotTaken.ExitingBlock) return SE->getCouldNotCompute();
   assert(ExitNotTaken.ExactNotTaken && "uninitialized not-taken info");
 
   const SCEV *BECount = 0;
@@ -4021,12 +4021,12 @@
 
 /// getExact - Get the exact not taken count for this loop exit.
 const SCEV *
-ScalarEvolution::BackedgeTakenInfo::getExact(BasicBlock *ExitBlock,
+ScalarEvolution::BackedgeTakenInfo::getExact(BasicBlock *ExitingBlock,
                                              ScalarEvolution *SE) const {
   for (const ExitNotTakenInfo *ENT = &ExitNotTaken;
        ENT != 0; ENT = ENT->getNextExit()) {
 
-    if (ENT->ExitBlock == ExitBlock)
+    if (ENT->ExitingBlock == ExitingBlock)
       return ENT->ExactNotTaken;
   }
   return SE->getCouldNotCompute();
@@ -4050,7 +4050,7 @@
   unsigned NumExits = ExitCounts.size();
   if (NumExits == 0) return;
 
-  ExitNotTaken.ExitBlock = ExitCounts[0].first;
+  ExitNotTaken.ExitingBlock = ExitCounts[0].first;
   ExitNotTaken.ExactNotTaken = ExitCounts[0].second;
   if (NumExits == 1) return;
 
@@ -4060,14 +4060,14 @@
   ExitNotTakenInfo *PrevENT = &ExitNotTaken;
   for (unsigned i = 1; i < NumExits; ++i, PrevENT = ENT, ++ENT) {
     PrevENT->setNextExit(ENT);
-    ENT->ExitBlock = ExitCounts[i].first;
+    ENT->ExitingBlock = ExitCounts[i].first;
     ENT->ExactNotTaken = ExitCounts[i].second;
   }
 }
 
 /// clear - Invalidate this result and free the ExitNotTakenInfo array.
 void ScalarEvolution::BackedgeTakenInfo::clear() {
-  ExitNotTaken.ExitBlock = 0;
+  ExitNotTaken.ExitingBlock = 0;
   ExitNotTaken.ExactNotTaken = 0;
   delete[] ExitNotTaken.getNextExit();
 }





More information about the llvm-commits mailing list
--- llvm/trunk/include/llvm/Analysis/ScalarEvolution.h (original)
+++ llvm/trunk/include/llvm/Analysis/ScalarEvolution.h Mon Aug  1 23:23:35 2011
@@ -264,11 +264,11 @@
     /// ExitNotTakenInfo - Information about the number of times a particular
     /// loop exit may be reached before exiting the loop.
     struct ExitNotTakenInfo {
-      BasicBlock *ExitBlock;
+      BasicBlock *ExitingBlock;
       const SCEV *ExactNotTaken;
       PointerIntPair<ExitNotTakenInfo*, 1> NextExit;
 
-      ExitNotTakenInfo() : ExitBlock(0), ExactNotTaken(0) {}
+      ExitNotTakenInfo() : ExitingBlock(0), ExactNotTaken(0) {}
 
       /// isCompleteList - Return true if all loop exits are computable.
       bool isCompleteList() const {
@@ -309,7 +309,7 @@
       /// computed information, or whether it's all SCEVCouldNotCompute
       /// values.
       bool hasAnyInfo() const {
-        return ExitNotTaken.ExitBlock || !isa<SCEVCouldNotCompute>(Max);
+        return ExitNotTaken.ExitingBlock || !isa<SCEVCouldNotCompute>(Max);
       }
 
       /// getExact - Return an expression indicating the exact backedge-taken
@@ -321,7 +321,7 @@
       /// getExact - Return the number of times this loop exit may fall through
       /// to the back edge. The loop is guaranteed not to exit via this block
       /// before this number of iterations, but may exit via another block.
-      const SCEV *getExact(BasicBlock *ExitBlock, ScalarEvolution *SE) const;
+      const SCEV *getExact(BasicBlock *ExitingBlock, ScalarEvolution *SE) const;
 
       /// getMax - Get the max backedge taken count for the loop.
       const SCEV *getMax(ScalarEvolution *SE) const;
@@ -711,9 +711,9 @@
                                      const SCEV *LHS, const SCEV *RHS);
 
     // getExitCount - Get the expression for the number of loop iterations for
-    // which this loop is guaranteed not to exit via ExitBlock. Otherwise return
-    // SCEVCouldNotCompute.
-    const SCEV *getExitCount(Loop *L, BasicBlock *ExitBlock);
+    // which this loop is guaranteed not to exit via ExitingBlock. Otherwise
+    // return SCEVCouldNotCompute.
+    const SCEV *getExitCount(Loop *L, BasicBlock *ExitingBlock);
 
     /// getBackedgeTakenCount - If the specified loop has a predictable
     /// backedge-taken count, return it, otherwise return a SCEVCouldNotCompute

Modified: llvm/trunk/lib/Analysis/ScalarEvolution.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Analysis/ScalarEvolution.cpp?rev=136677&r1=136676&r2=136677&view=diff
==============================================================================